#				SSBA 1.22F
#
# Makefile : doduc.mk
#
##############################################################################
SHELL=/bin/sh

.PRECIOUS:	run
.IGNORE:	

PRINTER	=	lp
PRINTOPT=	-l66
PAGER	=	more
COMPILER=	f77
LOCALOPT=	-O
FLOPT=		

FC	=	$(COMPILER) $(LOCALOPT) $(FLOPT)

NAME	=	doduc
README	=	${NAME}.doc ${NAME}.files
MAKEFILE=	${NAME}.mk ${NAME}.stan
CONFIG 	=	${NAME}.cf
RUN   	=	${NAME}.run
DATAS	=	${NAME}.dat
LOG	=	${NAME}.log
RES	=	${NAME}.res
JOU	=	${NAME}.jou
KILL	=	${NAME}.kill
TAR	=	${NAME}.tar
SHAR	=	${NAME}.shar
BANNER	=	${NAME}.ban
SOURCES =	F00111.f F00113.f F88345.f MAIN.f S00000.f S00001.f S00002.f \
		S00005.f S00006.f S00009.f S00011.f S00012.f S00013.f S00014.f \
		S00015.f S00017.f S00018.f S00019.f S00020.f S00022.f S00055.f \
		S00061.f S00089.f S00093.f S00096.f S00098.f S00099.f S00934.f \
		S22202.f S33018.f S33019.f S33022.f S33055.f S44553.f S55198.f \
		S55199.f S66832.f SI.f SIGMA.f X21Y21.f S00004.f
OBJECTS =	F00111.o F00113.o F88345.o MAIN.o S00000.o S00001.o S00002.o \
		S00005.o S00006.o S00009.o S00011.o S00012.o S00013.o S00014.o \
		S00015.o S00017.o S00018.o S00019.o S00020.o S00022.o S00055.o \
		S00061.o S00089.o S00093.o S00096.o S00098.o S00099.o S00934.o \
		S22202.o S33018.o S33019.o S33022.o S33055.o S44553.o S55198.o \
		S55199.o S66832.o SI.o SIGMA.o X21Y21.o S00004.o
TARGETS	=	${NAME}d
SSBALOG	=	../results/ssba.log
SSBASIZE=	../results/ssba.size
TRACE	=	1>>$(JOU) 2>&1
NUL	=	1>/dev/null 2>&1
ARCHIVES=	$(TAR) $(SHAR)
VOLATILE=	$(JOU) $(LOG) $(RES) $(KILL) $(OBJECTS) $(TARGETS)\
		$(ARCHIVES) core
SCRIPTS	=	$(MAKEFILE) $(CONFIG) $(RUN)
FILES	=	$(BANNER) $(README) $(SCRIPTS) $(DATAS) $(SOURCES)

conf:
		@chmod u+x $(CONFIG)
		@./$(CONFIG)

compile:	$(TARGETS)

run:		$(DATAS)
		@./$(RUN)
sizes:
		@ls -l $(TARGETS) | tee -a $(SSBASIZE)
clean:
		@rm -f $(VOLATILE) $(NUL)
readme:
		@$(PAGER) $(README)
print:
		@pr $(PRINTOPT) -h $(NAME) $(SCRIPTS) | $(PRINTER)
printall:
		@pr $(PRINTOPT) -h $(NAME) $(FILES) | $(PRINTER)
tar:
		@tar cf $(TAR) $(FILES)
shar:
		@shar $(FILES) > $(SHAR)
force:

$(BANNER):
		@banner $(NAME) >$@

${NAME}d:	$(OBJECTS)
		$(FC) $(OBJECTS) -o $@	$(TRACE)

F00111.o:	F00111.f
		$(FC) -c F00111.f	$(TRACE)
F00113.o:	F00113.f
		$(FC) -c F00113.f	$(TRACE)
F88345.o:	F88345.f
		$(FC) -c F88345.f	$(TRACE)
MAIN.o:		MAIN.f
		$(FC) -c MAIN.f	$(TRACE)
S00000.o:	S00000.f
		$(FC) -c S00000.f	$(TRACE)
S00001.o:	S00001.f
		$(FC) -c S00001.f	$(TRACE)
S00002.o:	S00002.f
		$(FC) -c S00002.f	$(TRACE)
S00004.o:	S00004.f
		$(FC) -c S00004.f	$(TRACE)
S00005.o:	S00005.f
		$(FC) -c S00005.f	$(TRACE)
S00006.o:	S00006.f
		$(FC) -c S00006.f	$(TRACE)
S00009.o:	S00009.f
		$(FC) -c S00009.f	$(TRACE)
S00011.o:	S00011.f
		$(FC) -c S00011.f	$(TRACE)
S00012.o:	S00012.f
		$(FC) -c S00012.f	$(TRACE)
S00013.o:	S00013.f
		$(FC) -c S00013.f	$(TRACE)
S00014.o:	S00014.f
		$(FC) -c S00014.f	$(TRACE)
S00015.o:	S00015.f
		$(FC) -c S00015.f	$(TRACE)
S00017.o:	S00017.f
		$(FC) -c S00017.f	$(TRACE)
S00018.o:	S00018.f
		$(FC) -c S00018.f	$(TRACE)
S00019.o:	S00019.f
		$(FC) -c S00019.f	$(TRACE)
S00020.o:	S00020.f
		$(FC) -c S00020.f	$(TRACE)
S00022.o:	S00022.f
		$(FC) -c S00022.f	$(TRACE)
S00055.o:	S00055.f
		$(FC) -c S00055.f	$(TRACE)
S00061.o:	S00061.f
		$(FC) -c S00061.f	$(TRACE)
S00089.o:	S00089.f
		$(FC) -c S00089.f	$(TRACE)
S00093.o:	S00093.f
		$(FC) -c S00093.f	$(TRACE)
S00096.o:	S00096.f
		$(FC) -c S00096.f	$(TRACE)
S00098.o:	S00098.f
		$(FC) -c S00098.f	$(TRACE)
S00099.o:	S00099.f
		$(FC) -c S00099.f	$(TRACE)
S00934.o:	S00934.f
		$(FC) -c S00934.f	$(TRACE)
S22202.o:	S22202.f
		$(FC) -c S22202.f	$(TRACE)
S33018.o:	S33018.f
		$(FC) -c S33018.f	$(TRACE)
S33019.o:	S33019.f
		$(FC) -c S33019.f	$(TRACE)
S33022.o:	S33022.f
		$(FC) -c S33022.f	$(TRACE)
S33055.o:	S33055.f
		$(FC) -c S33055.f	$(TRACE)
S44553.o:	S44553.f
		$(FC) -c S44553.f	$(TRACE)
S55198.o:	S55198.f
		$(FC) -c S55198.f	$(TRACE)
S55199.o:	S55199.f
		$(FC) -c S55199.f	$(TRACE)
S66832.o:	S66832.f
		$(FC) -c S66832.f	$(TRACE)
SI.o:		SI.f
		$(FC) -c SI.f		$(TRACE)
SIGMA.o:	SIGMA.f
		$(FC) -c SIGMA.f	$(TRACE)
X21Y21.o:	X21Y21.f
		$(FC) -c X21Y21.f	$(TRACE)
