#	STANFORD		SSBA 1.22F
#
# Makefile : linpack.stan
#
#############################################################################
SHELL=/bin/sh

.PRECIOUS:	run
.IGNORE:	

PRINTER	=	lp
PRINTOPT=	-l66
PAGER	=	more
COMPILER=	f77
LOCALOPT=	-O
FLOPT=		

FFLAGS	=	-j
ETIME	=	../config/etime.o

FC	=	$(COMPILER) $(LOCALOPT) $(FLOPT) $(FFLAGS)
LD	=	$(COMPILER) $(LOCALOPT) $(FLOPT)

NAME	=	linpack
README	=	${NAME}.doc ${NAME}.files
MAKEFILE=	${NAME}.mk ${NAME}.stan
CONFIG 	=	${NAME}.cf
RUN   	=	${NAME}.run
LOG	=	${NAME}.log
RES	=	${NAME}.res
JOU	=	${NAME}.jou
KILL	=	${NAME}.kill
TAR	=	${NAME}.tar
SHAR	=	${NAME}.shar
BANNER	=	${NAME}.ban
SSBALOG	=	../results/ssba.log
SSBASIZE=	../results/ssba.size
TRACE	=	1>>$(JOU) 2>&1
NUL	=	1>/dev/null 2>&1
SOURCES	=	${NAME}rs.f ${NAME}rd.f ${NAME}us.f ${NAME}ud.f
OBJECTS	=	${NAME}rs.u ${NAME}rd.u ${NAME}us.u ${NAME}ud.u \
		${NAME}rs.o ${NAME}rd.o ${NAME}us.o ${NAME}ud.o
TARGETS	=	${NAME}rd   ${NAME}rs   ${NAME}ud   ${NAME}us 
ARCHIVES=	$(TAR) $(SHAR)
VOLATILE=	$(JOU) $(LOG) $(RES) $(KILL) $(OBJECTS) $(TARGETS) \
		$(ARCHIVES) core
SCRIPTS	=	$(MAKEFILE) $(CONFIG) $(RUN)
FILES	=	$(BANNER) $(README) $(SCRIPTS) $(SOURCES)

conf:
		@chmod u+x $(CONFIG)
		@./$(CONFIG)

compile:	$(TARGETS)

run:
		@./$(RUN)
sizes:
		@ls -l $(TARGETS) | tee -a $(SSBASIZE)
clean:
		@rm -f $(VOLATILE) $(NUL)
readme:
		@$(PAGER) $(README)
print:
		@pr $(PRINTOPT) -h $(NAME) $(SCRIPTS) | $(PRINTER)
printall:
		@pr $(PRINTOPT) -h $(NAME) $(FILES) | $(PRINTER)
tar:
		@tar cf $(TAR) $(FILES)
shar:
		@shar $(FILES) > $(SHAR)
force:

$(BANNER):
		@banner $(NAME) >$@

${NAME}rs:	${NAME}rs.u $(ETIME)
		$(LD) $@.u $(ETIME) -o $@	$(TRACE)
		-@rm ${NAME}rs.u ${NAME}rs.o
${NAME}rd:	${NAME}rd.u $(ETIME)
		$(LD) $@.u $(ETIME) -o $@	$(TRACE)
		-@rm ${NAME}rd.u ${NAME}rd.o
${NAME}us:	${NAME}us.u $(ETIME)
		$(LD) $@.u $(ETIME) -o $@	$(TRACE)
		-@rm ${NAME}us.u ${NAME}us.o
${NAME}ud:	${NAME}ud.u $(ETIME)
		$(LD) $@.u $(ETIME) -o $@	$(TRACE)
		-@rm ${NAME}ud.u ${NAME}ud.o
${NAME}rs.u:	${NAME}rs.f
		$(FC) ${NAME}rs.f		$(TRACE)
${NAME}rd.u:	${NAME}rd.f
		$(FC) ${NAME}rd.f		$(TRACE)
${NAME}us.u:	${NAME}us.f
		$(FC) ${NAME}us.f		$(TRACE)
${NAME}ud.u:	${NAME}ud.f
		$(FC) ${NAME}ud.f		$(TRACE)
${ETIME}:	../config/etime.c
		make $@ -f ../config/config.mk
