#	STANFORD		SSBA 1.22F
#
# Makefile : whet.stan
#
##############################################################################
SHELL=/bin/sh

.PRECIOUS:	run
.IGNORE:	

PRINTER	=	lp
PRINTOPT=	-l66
PAGER	=	more
COMPILER=	f77
LOCALOPT=	-O
FLOPT=		

FFLAGS	=	-j
ETIME	=	../config/etime.o

FC	=	$(COMPILER) $(LOCALOPT) $(FLOPT) $(FFLAGS)
LD	=	$(COMPILER) $(LOCALOPT) $(FLOPT)

NAME	=	whet
README	=	${NAME}.doc ${NAME}.files
MAKEFILE=	${NAME}.mk ${NAME}.stan
CONFIG  =	${NAME}.cf
RUN    =	${NAME}.run
DATAS	=	${NAME}.dat
LOG	=	${NAME}.log
RES	=	${NAME}.res
JOU	=	${NAME}.jou
KILL	=	${NAME}.kill
TAR	=	${NAME}.tar
SHAR	=	${NAME}.shar
BANNER	=	${NAME}.ban
SOURCES	=	${NAME}s.f ${NAME}d.f
OBJECTS	=	${NAME}s.u ${NAME}d.u ${NAME}s.o ${NAME}d.o
TARGETS	=	${NAME}s ${NAME}d
SSBALOG	=	../results/ssba.log
SSBASIZE=	../results/ssba.size
TRACE	=	1>>$(JOU) 2>&1
NUL	=	1>/dev/null 2>&1
ARCHIVES=	$(TAR) $(SHAR)
VOLATILE=	$(JOU) $(LOG) $(RES) $(KILL) $(OBJECTS) $(TARGETS)\
		$(ARCHIVES) core
SCRIPTS =	$(MAKEFILE) $(CONFIG) $(RUN)
FILES	=	$(BANNER) $(README) $(SCRIPTS) $(SOURCES)

conf:
		@chmod u+x $(CONFIG)
		@./$(CONFIG)

compile:	$(TARGETS)

run:		$(DATAS)
		@./$(RUN)
sizes:
		@ls -l $(TARGETS) | tee -a $(SSBASIZE)
clean:
		@rm -f $(VOLATILE) $(NUL)
readme:
		@$(PAGER) $(README)
print:
		@pr $(PRINTOPT) -h $(NAME) $(SCRIPTS) | $(PRINTER)
printall:
		@pr $(PRINTOPT) -h $(NAME) $(FILES) | $(PRINTER)
tar:
		@tar cf $(TAR) $(FILES)
shar:
		@shar $(FILES) > $(SHAR)
force:

$(BANNER):
		@banner $(NAME) >$@

${NAME}s:	${NAME}s.u $(ETIME)
		$(LD) ${NAME}s.u $(ETIME) -o $@		$(TRACE)
		-@rm ${NAME}s.u ${NAME}s.o
${NAME}d:	${NAME}d.u $(ETIME)
		$(LD) ${NAME}d.u $(ETIME) -o $@		$(TRACE)
		-@rm ${NAME}d.u ${NAME}d.o
${NAME}s.u:	${NAME}s.f
		$(FC) ${NAME}s.f			$(TRACE)
${NAME}d.u:	${NAME}d.f
		$(FC) ${NAME}d.f			$(TRACE)
${ETIME}: 	../config/etime.c
		make $@ -f ../config/config.mk
